<template>
    <div class="settings">
        <h1 class="header">Настройки профиля</h1>
        <div class="lds-dual-ring" v-if="isLoading"></div>
        <div v-else>
            <div class="group">
                <span>Скрывать ссылки на соц. сети?</span>
                <div>
                    <input type="radio" value="1" v-model="social" />
                    <label @click="social = 1">Да</label>

                    <input type="radio" value="0" v-model="social" />
                    <label @click="social = 0">Нет</label>
                </div>
            </div>
            <div class="group">
                <span>Запретить переводы?</span>
                <div>
                    <input type="radio" value="1" v-model="transfer" />
                    <label @click="transfer = 1">Да</label>

                    <input type="radio" value="0" v-model="transfer" />
                    <label @click="transfer = 0">Нет</label>
                </div>
            </div>
            <button 
                class="btn-outline__body" 
                @click="updateAvatar"
            >
                Загрузить аватарку с вк
            </button>
            <button 
                class="btn-primary__body" 
                :disabled="btnLoading"
                @click="save"
            >
                Сохранить
            </button>
        </div>
    </div>
</template>

<script>
export default {
    data() {
        return {
            username: null,
            social: 0,
            transfer: 0,
            isLoading: true,
            btnLoading: false
        }
    },
    mounted() {
        this.init()
    },
    methods: {
        init() {
            this.$root.axios.post('/profile/getSettings')
            .then(response => {
                const {data} = response

                this.username = data.username
                this.social = data.social
                this.transfer = data.transfer
                this.isLoading = false
            })
        },
        save() {
            this.btnLoading = true
            this.$root.axios.post('/profile/save', {
                privacy_hide: this.social,
                privacy_hide_transfer: this.transfer,
                username: this.username
            })
            .then(response => {
                const {data} = response
                this.btnLoading = false

                if(data.error) {
                    return notify({
                        theme: 'red',
                        text: data.message
                    })
                }

                notify({
                    theme: 'green',
                    text: 'Изменения сохранены'
                })

                this.$root.user.login = data.username
            })
        },
        updateAvatar() {
            location.href = '/auth/vkontakte'
        }
    }
}
</script>

<style scoped>
.settings {
    padding: 32px 57px;
    background: #fff;
    border-radius: 0 0 8px 8px;
}

.header {
  margin: 0 0 1rem;
}

.group {
    display: flex;
    flex-direction: column;
}

.group:not(first-children) {
    margin-top: 16px
}

.group > div {
    min-width: 100px;
    display: flex;
    justify-content: space-between;
    max-width: 110px;
}

span {
    margin-bottom: 10px
}

label {
    cursor: pointer
}

input:not([type="radio"]) {
    background: #eeecfd;
    padding: 16px 21px;
    border: 1px solid #dcd9f7;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-box-shadow: 0 5px 35px rgba(215, 211, 236, 0.25);
    box-shadow: 0 5px 35px rgba(215, 211, 236, 0.25);
    border-radius: 4px;
    font-size: 13px;
    line-height: 15px;
    width: 100%;
    max-height: 50px;
    max-width: 320px;
}

button {
    margin-top: 20px;
    max-width: 320px
}

.lds-dual-ring {
    display: flex;
    margin: auto;
    width: 80px;
    height: 80px;
}
.lds-dual-ring:after {
    content: " ";
    display: block;
    width: 40px;
    height: 40px;
    margin: auto;
    border-radius: 50%;
    border: 2px solid #e6e4f1;
    border-top-color: rgb(230, 228, 241);
    border-right-color: rgb(230, 228, 241);
    border-bottom-color: rgb(230, 228, 241);
    border-left-color: rgb(230, 228, 241);
    border-color: #e6e4f1 transparent #e6e4f1 transparent;
    animation: lds-dual-ring-data-v-314fa2e8 1.2s linear infinite;
}
@keyframes lds-dual-ring {
    0% {
        transform: rotate(0deg);
    }
    100% {
        transform: rotate(360deg);
    }
}
</style>